.. image:: _static/gamma_pytools_logo.png

|

Table of contents
-----------------

.. toctree::
   :maxdepth: 1
   :titlesonly:

   Getting started <getting_started/getting_started>
   API reference <apidoc/pytools>
   contribution_guide
   faqs
   release_notes
